;****************************************************************************************
;*                           SERVO-TESTER                                               * 
;*                           ============                                               *
;*                           24.01.20                                                   *
;****************************************************************************************

        LIST    P=16F88       
        TITLE   "BATTERIE-ABSCHALT"

        ERRORLEVEL -302
        INCLUDE <P16F88.INC>

__CONFIG _CONFIG1, _CP_OFF & _CCPMX_RB0 & _DEBUG_OFF & _WRT_OFF & _CPD_OFF & _LVP_OFF & _BOREN_ON & _MCLRE_OFF & _PWRTE_OFF & _WDTE_OFF & _FOSC_HS
__CONFIG _CONFIG2, _IESO_OFF & _FCMEN_OFF

;--------------------------------------------------------------------------
;MIT QUARZ 16,000MHZ
;T=1 : F  T=1 : 16MHZ = 0,0625SEC
;MEIST T=4 DANN 0,25SEC        
;--------------------------------------------------------------------------
;REGISTER ZUORDNEN NACH DEM DIE FESTEN-REGISTER ZU ENDE SIND
;ES GEHT ALSO ERST AB 22 HEX LOS
;DIES IST ALSO DIE RAM-SPEICHER ZUORDNUNG

;FUER ZEITSCHLEIFEN 
HELP0   EQU 0X22       
   
;ANALOG/DIGITAL-WANDLUNG
AD_H    EQU 0X23
AD_L    EQU 0X24

;FUER LCD-DISPLAY    
MERKE  EQU  0X25                                              
BIT    EQU  0X26
HELP2  EQU  0X27
  
;FR INTERRUPT
W_STACK EQU 0X28
S_STACK EQU 0X29

;FUER HEX IN BCD
TEM     EQU 0X2A
TEM_L   EQU 0X2B
TEM_H   EQU 0X2C   
ANZ_L   EQU 0X2D
ANZ_H   EQU 0X2E
ZAE     EQU 0X2F
VER     EQU 0X30     
 
;FUER SERVO STELLEN     
IMPULS_L    EQU 0X31
IMPULS_H    EQU 0X32    
       
       
;============================================================================  *
RS     EQU 2       ; PORTA BIT2 UMSCHALTEN BEFEHL/DATEN                        *
;                  ; BEI WRITE DATEN IST ES HIGH / BEI LOW IST ES EIN BEFEHL   *
EN     EQU 3       ; PORTA BIT3 ENABLE FALLENDE FLANKE                         *
;============================================================================  * 

;------------------------- MACROS -----------------------------------------

BANK0           MACRO                   ;MACRO TO SELECT DATA RAM BANK 0
                BCF     STATUS,RP0
                BCF     STATUS,RP1
                ENDM

BANK1           MACRO                   ;MACRO TO SELECT DATA RAM BANK 1
                BSF     STATUS,RP0
                BCF     STATUS,RP1
                ENDM

BANK2           MACRO                   ;MACRO TO SELECT DATA RAM BANK 2
                BCF     STATUS,RP0
                BSF     STATUS,RP1
                ENDM

BANK3           MACRO                   ;MACRO TO SELECT DATA RAM BANK 3
                BSF     STATUS,RP0
                BSF     STATUS,RP1
                ENDM

;------------ MACROS FUER INTERRUPT -----------------------------------------
;WENN EINE UNTERBRECHUNG VOM EIGENTLICHEN PROGRAMM KOMMT, MUSS REGISTER "W" UND "STATUS" GERETTET/GEMERKT WERDEN.
;DIES PASSIERT MITTELS RAM-SPEICHERZELLEN W_STACK UND S_STACK

PUSH    MACRO
        MOVWF   W_STACK
        MOVF    STATUS, W
        MOVWF   S_STACK
        ENDM
;----------------------------------------------------------------------------

;WENN DAS INTERRUPT-PROGRAMM ABGEARBEITET IST (ZU ENDE IST), MSSEN DIE GEMERKTEN/GERETTEN REGISTER "W" UND "STATUS"
;WIEDER HERVORGEHOLT WERDEN, UM IM EIGENTLICHEN PROGRAMM WEITER ZU ARBEITEN

POP     MACRO
        MOVF    S_STACK, W
        MOVWF   STATUS
        SWAPF   W_STACK, F
        SWAPF   W_STACK, W
        ENDM
;----------------------------------------------------------------------------

;VARIABLEN
BIT7    EQU 7       ; BIT 7
BIT6    EQU 6       ; BIT 6
BIT5    EQU 5       ; BIT 5
BIT4    EQU 4       ; BIT 4
BIT3    EQU 3       ; BIT 3 
BIT2    EQU 2       ; BIT 2
BIT1    EQU 1       ; BIT 1 
BIT0    EQU 0       ; BIT 0

 
    

;-----------------------------------------------------------------------------
;SPEICHERANFANG BZW. BEGINN

                ORG 0X0000
                GOTO MAIN               ; SPRUNG ZUM HAUPTPROGRAMM
                ORG 0X0004
                RETFIE                  ;GOTO NICHT INTERRUPT

                ORG 0X0010    
;*****************************************************************************
;*                              HAUPTPROGRAMM                                *
;*****************************************************************************
MAIN                       
                CLRF    PORTB
                CLRF    PORTA  
                

;----------- INIT ALLE PORT'S ----------------------------------------------------

                BANK1
                MOVLW   B'01100100'             ;0010-16MHZ EXTERN / / 1-STABILE FREQUENZ / /// WAHLLOS 0110 VORN ALS 4MHZ INTERN...
                MOVWF   OSCCON

                MOVLW   0X07                    ;COMPARATORS ALLE AUS VOM PORT A
                MOVWF   CMCON

                MOVLW   B'00100011'             ;INIT INPUT/OUTPUT AM PORTA  RA2=RS / RA3=E DISPLAY RA1 ALS AN1-EINGANG
                MOVWF   TRISA
                MOVLW   B'00001111'             ;INIT I/O PORTB  RB7-RB4 AUSGANG / 1111 ALS RB0-RB3 EINGNGE
                MOVWF   TRISB

;INIT TIMER 0 
                MOVLW   B'10000111'             ;BIT0-2 1=PRESCALER256, BIT3 0=TMR0, BIT4 0=ENTFAELLT, BIT5 0=TAKT VOM SYSTEM, BIT6 0=KEIN RB-INTERRUPT, BIT7 1=PULL-UPS DISABLE 
                MOVWF   OPTION_REG
                

;AD-INIT
                MOVLW   B'00000010' ; AN1         
                MOVWF   ANSEL
;AD-INIT
                MOVLW   B'10000000'  ;RECHTSBNDIG B1 / B0 / VSS+VDD-SPANNUNG B00
                MOVWF   ADCON1
                BANK0
;AD-INIT
                MOVLW   B'01001001'  ;FOSZ/8 B01 / AN1 B000 / GO-IST AUS + ON IST EIN B001
                MOVWF   ADCON0                
                

                 ;ZEITSCHLEIFE 50MSEC                
                MOVLW   D'5'       ;5*10MSEC=50MSEC
                CALL    ZS10MSEC

                BCF     PORTA, BIT4         ;IMPULS SCHLUSS AUF LOW
                          
                
;INITIALISIERUNG DOT-MATRIX-LCD
;IM HAUPTPROGRAMM (MAIN) AM ANFANG EINTRAGEN
            MOVLW   H'20'                   ;FUNCTION SET  4-BIT-LAENGE, 2ZEILIG 2X16ZEICHEN, 5X7FONT
            CALL    BEFEHL                  ;FR 1-ZEILIG 1X8ZEICHEN H'20' EINTRAGEN

            MOVLW   H'0C'                   ;DISPLAY ON/OFF   DISPLAY ON, CURSOR OFF, BLINK OFF
            CALL    BEFEHL
            CALL    LOE
            
            CALL    GEHTLOS
            
            MOVLW   D'250'                  ;2SEC ZEITSCHLEIFE
            CALL    ZS10MSEC
            
            MOVLW   D'250'                  ;2SEC ZEITSCHLEIFE
            CALL    ZS10MSEC
            
            CALL    LOE
            
            CALL    MS
            
NOCHMAL            
            CALL    AD
            
            CALL    BCD_ANZEIGE
             
            CALL    STELLEN
            
            GOTO    NOCHMAL
            
;*****************************************************************************
;*                              SERVO STELLEN                                *
;*****************************************************************************
STELLEN
            BSF     PORTA, BIT4         ;IMPULS GEHT LOS AUF HIGH
            
;200MSEC ZEITSCHLEIFE BEGINN STARR            

;1XNOP= 4TAKTE * 0,0625SEC = 0,25SEC * 40XNOPS = 10SEC
;200SEC : 10SEC = 20 MAL 
            
            MOVLW   D'20'
            MOVWF   HELP0
            
ST          NOP
            NOP
            NOP
            NOP
            NOP
            
            NOP
            NOP
            NOP
            NOP
            NOP
            
            NOP
            NOP
            NOP
            NOP
            NOP
            
            NOP
            NOP
            NOP
            NOP
            NOP
            
            NOP
            NOP
            NOP
            NOP
            NOP
            
            NOP
            NOP
            NOP
            NOP
            NOP
            
            NOP
            NOP
            NOP
            NOP
            NOP
            
            NOP
            NOP
            ;NOP    WEG WEGEN ZEIT VON DECFSZ + GOTO
            ;NOP
            ;NOP
            
            DECFSZ  HELP0, F
            GOTO    ST
            
            
;MIT POTI SERVO STELLEN / GEMESSENE WERTE AM POTI
;---------------------------------------------------            
;0.25MYS (BEI 1XNOPS) 
;10SEC : 0.25SEC = 40 MAL NOP            

ZS          NOP
            NOP
            NOP
            NOP
            NOP
            
            NOP
            NOP
            NOP
            NOP
            NOP
            
            NOP
            NOP
            NOP
            NOP
            NOP
            
            NOP
            NOP
            NOP
            NOP
            NOP
            
            NOP
            NOP
            NOP
            NOP
            NOP
            
            NOP
            NOP
            NOP
            NOP
            NOP
            
            NOP
            NOP
            NOP
            NOP
            NOP
            
            NOP
            NOP
            ;NOP    WEG WEGEN ZEIT VON DECFSZ + GOTO
            ;NOP
            ;NOP

            DECFSZ  IMPULS_L, F
            GOTO    ZS
            
;---------------------------------------------------            
            
SCHLUSS
            BCF     PORTA, BIT4         ;IMPULS SCHLUSS AUF LOW
            
;ZEITSCHLEIFE 20MSEC/ ALSO PAUSE ZWISCHEN IMPULSEN
            MOVLW   D'2'
            CALL    ZS10MSEC
            RETURN          
            
;*****************************************************************************
;*                              AD-MESSUNG                                   *
;*****************************************************************************
AD              BCF     PIR1, ADIF 
                BSF     ADCON0, GO_DONE  ;GEHT LOS DIE MESSUNG
                CALL    MUE100

AD2             BTFSS   PIR1, ADIF
                GOTO    AD2

                BCF     ADCON0, GO_DONE  ;STOP DER MESSUNG

;AD-ERGEBNIS ABSPEICHERN IN RAM-ZELLEN AD_H UND AD_L
                MOVF    ADRESH, W
                MOVWF   TEM_H
                BANK1                               
                MOVF    ADRESL, W
                BANK0                               
                MOVWF   TEM_L
                
;BERECHNUNG
                RRF     TEM_H, F
                RRF     TEM_L, F
                BCF     STATUS, C
                
                RRF     TEM_H, F
                RRF     TEM_L, F
;MERKER FUER STELLEN
                MOVF    TEM_L, W
                MOVWF   IMPULS_L
                SUBLW   0X00
                BTFSC   STATUS, Z
                INCF    IMPULS_L, F
                 
                MOVLW   D'20'
                ADDWF   TEM_L, F
                BTFSS   STATUS, C
                GOTO    AD_0
                INCF    TEM_H, F
                

 
AD_0            RETURN
 
           
;*****************************************************************************
;*                        UNTERPROGRAMM BCD-UMRECHNUNG UND ANZEIGE           *
;*                        DIES IST NUR MAL GANZ SCHNELL ZUSAMMEN GEPFUSCHT   *
;*                        DESHALB STEHEN NUR GANZ WENIGE KOMMENTARE DRIN     *
;*                              31.03.11                                     *
;*****************************************************************************
BCD_ANZEIGE 
            MOVF    TEM_L, W
            MOVWF   TEM
            
            CLRF    ANZ_L
            CLRF    ANZ_H
            
            BTFSS   TEM, BIT0
            GOTO    W001
            MOVLW   0X01
            MOVWF   ANZ_L

W001        BTFSS   TEM, BIT1
            GOTO    W002
            MOVF    ANZ_L, W
            ADDLW   0X02
            MOVWF   ANZ_L

W002        BTFSS   TEM, BIT2
            GOTO    W003
            MOVF    ANZ_L, W
            ADDLW   0X04
            MOVWF   ANZ_L

;-------

W003        BTFSS   TEM, BIT3
            GOTO    W004
            MOVLW   D'8'
            MOVWF   ZAE

W003B       INCF    ANZ_L, F
            MOVF    ANZ_L, W
            ANDLW   0X0F
            MOVWF   VER
            MOVLW   0X0A
            SUBWF   VER, W
            BTFSS   STATUS, Z
            GOTO    W003A
            MOVF    ANZ_L, W
            ANDLW   0XF0
            ADDLW   0X10
            MOVWF   ANZ_L

W003A       DECFSZ  ZAE, F
            GOTO    W003B

;--------

W004        BTFSS   TEM, BIT4
            GOTO    W005
            MOVLW   D'16'
            MOVWF   ZAE

W004B       INCF    ANZ_L, F
            MOVF    ANZ_L, W
            ANDLW   0X0F
            MOVWF   VER
            MOVLW   0X0A
            SUBWF   VER, W
            BTFSS   STATUS, Z
            GOTO    W004A
            MOVF    ANZ_L, W
            ANDLW   0XF0
            ADDLW   0X10
            MOVWF   ANZ_L

W004A       DECFSZ  ZAE, F
            GOTO    W004B

;--------

W005        BTFSS   TEM, BIT5
            GOTO    W006
            MOVLW   D'32'
            MOVWF   ZAE

W005B       INCF    ANZ_L, F
            MOVF    ANZ_L, W
            ANDLW   0X0F
            MOVWF   VER
            MOVLW   0X0A
            SUBWF   VER, W
            BTFSS   STATUS, Z
            GOTO    W005A
            MOVF    ANZ_L, W
            ANDLW   0XF0
            ADDLW   0X10
            MOVWF   ANZ_L 

W005A       DECFSZ  ZAE, F
            GOTO    W005B

;--------

W006        BTFSS   TEM, BIT6
            GOTO    W007
            MOVLW   D'64'
            MOVWF   ZAE

W006B       INCF    ANZ_L, F
            MOVF    ANZ_L, W
            ANDLW   0X0F
            MOVWF   VER
            MOVLW   0X0A
            SUBWF   VER, W
            BTFSS   STATUS, Z
            GOTO    W006A
            MOVF    ANZ_L, W
            ANDLW   0XF0
            ADDLW   0X10
            MOVWF   ANZ_L

            MOVF    ANZ_L, W
            ANDLW   0XF0
            MOVWF   VER 
            MOVLW   0XA0
            SUBWF   VER, W
            BTFSS   STATUS, Z
            GOTO    W006A
            CLRF    ANZ_L
            MOVF    ANZ_H, W
            ANDLW   0X0F
            ADDLW   0X01
            MOVWF   ANZ_H

W006A       DECFSZ  ZAE, F
            GOTO    W006B

;--------

W007        BTFSS   TEM, BIT7
            GOTO    W008
            MOVLW   D'128'
            MOVWF   ZAE

W007B       INCF    ANZ_L, F
            MOVF    ANZ_L, W
            ANDLW   0X0F
            MOVWF   VER
            MOVLW   0X0A
            SUBWF   VER, W
            BTFSS   STATUS, Z
            GOTO    W007A
            MOVF    ANZ_L, W
            ANDLW   0XF0
            ADDLW   0X10
            MOVWF   ANZ_L

            MOVF    ANZ_L, W
            ANDLW   0XF0
            MOVWF   VER
            MOVLW   0XA0
            SUBWF   VER, W
            BTFSS   STATUS, Z
            GOTO    W007A
            CLRF    ANZ_L
            MOVF    ANZ_H, W
            ANDLW   0X0F
            ADDLW   0X01
            MOVWF   ANZ_H

W007A       DECFSZ  ZAE, F
            GOTO    W007B

      
;--------

W008        BTFSS   TEM_H, BIT0 ;ACHTUNG
            GOTO    W009
            MOVLW   D'255'
            MOVWF   ZAE
            
W008B       INCF    ANZ_L, F
            MOVF    ANZ_L, W
            ANDLW   0X0F
            MOVWF   VER
            MOVLW   0X0A
            SUBWF   VER, W
            BTFSS   STATUS, Z
            GOTO    W008A
            MOVF    ANZ_L, W
            ANDLW   0XF0
            ADDLW   0X10
            MOVWF   ANZ_L

            MOVF    ANZ_L, W
            ANDLW   0XF0
            MOVWF   VER
            MOVLW   0XA0
            SUBWF   VER, W
            BTFSS   STATUS, Z
            GOTO    W008A
            CLRF    ANZ_L
            MOVF    ANZ_H, W
            ANDLW   0X0F
            ADDLW   0X01
            MOVWF   ANZ_H

W008A       DECFSZ  ZAE, F
            GOTO    W008B

;ACHTUNG +1 WEGEN D'255' UND NICHT 256
            INCF    ANZ_L, F
            MOVF    ANZ_L, W
            ANDLW   0X0F
            MOVWF   VER
            MOVLW   0X0A
            SUBWF   VER, W
            BTFSS   STATUS, Z
            GOTO    W009    ;ACHTUNG
            MOVF    ANZ_L, W
            ANDLW   0XF0
            ADDLW   0X10
            MOVWF   ANZ_L

            MOVF    ANZ_L, W
            ANDLW   0XF0
            MOVWF   VER
            MOVLW   0XA0
            SUBWF   VER, W
            BTFSS   STATUS, Z
            GOTO    W009    ;ACHTUNG
            CLRF    ANZ_L
            MOVF    ANZ_H, W
            ANDLW   0X0F
            ADDLW   0X01
            MOVWF   ANZ_H
            
            
            
;------------
;BCD-ANZEIGE

W009
            MOVLW   H'80'                   ;ADRESSE 0                  
            CALL    BEFEHL
            MOVF    ANZ_H, W
            ANDLW   H'0F'
            ADDLW   H'30'
            CALL    DATEN

            MOVLW   H'83'                   ;ADRESSE 3
            CALL    BEFEHL
            MOVF    ANZ_L, W
            ANDLW   H'0F'
            ADDLW   H'30'
            CALL    DATEN

            MOVLW   H'82'                   ;ADRESSE 2
            CALL    BEFEHL
            SWAPF   ANZ_L, W
            ANDLW   H'0F'
            ADDLW   H'30'
            CALL    DATEN

            RETURN

      
;*****************************************************************************
;*                              100S ZEITSCHLEIFE                           *
;*****************************************************************************

MUE100      MOVLW   D'40'   ;40*2,5SEC=100SEC 
            MOVWF   HELP0
M1          NOP             ;10X NOP (1X T=4) ALSO T=40*0.0625S=2,5SEC
            NOP         
            NOP
            NOP
            NOP
            NOP
            NOP
            NOP
            NOP
            NOP
            DECFSZ  HELP0, F
            GOTO    M1
            RETURN
               
;*****************************************************************************
;*         UNTERPROGRAMM MIT TIMER0 ALS ZEITSCHLEIFE FUER  10MSEC ....       *
;*                                                                           *
;*****************************************************************************
ZS10MSEC                MOVWF   HELP0                   ;DER INHALT VON W WIRD IN "HELP1" GELADEN

T01                     MOVLW   D'192'
                        MOVWF   TMR0                    ;DER FESTE RAM-SPEICHER (TMR0) WIRD MIT 217 GELADEN
                        BCF     INTCON, TMR0IF            ;OVERFLOW = 0
                
T02                     BTFSS   INTCON, TMR0IF            ;WENN DIE ZEIT VON 10MSEC ABGELAUFEN IST, WIRD T0IF HIGH (1) UND 
                        GOTO    T02                     ;ES ERFOLGT EIN SPRUNG ZU "DECFSC MERK, F"
                        
                        DECFSZ  HELP0, F                ;ES WIRD DER WERT IN "HELP1" ABWRTS GEZHLT, BIS ER (0) IST UND
                        GOTO    T01                     ;DANN ERFOLGT EIN SPRUNG ZU "RETURN"-ENDE DES UNTERPROGRAMMS
                        RETURN

;ZEITBERECHNUNG FUER 10MS
;PRESCALER 256X  *  SYSTEM 4X  * TAKTZEIT ====> 256*4*0.0625SEC=64SEC       /DIE TAKTZEIT ERGIBT SICH AUS DEM INTERNEN OSZILLATOR
;10MS : 64SEC= 156                                                           /T = 1 : F  (F)-OSZILLATORFREQUENZ
;ALSO
;64S*D'156'=9,984MSEC
;TMR0 ALSO D'256'-D'64'=D'192' ENTSPRICHT CA. 10MSEC
;192 DEZIMAL OBEN EINTRAGEN
                        

;*****************************************************************************
;*                              UNTERPROG. DATEN AUSGEBEN AUF DOT-LCD-MODUL  *
;*****************************************************************************
DATEN       BSF     PORTA, RS               ;ALS DATEN

            MOVWF   BIT

            MOVF    PORTB, W
            ANDLW   0X0F
            MOVWF   MERKE

            MOVF    BIT, W
            ANDLW   0XF0
            ADDWF   MERKE, W
            MOVWF   PORTB


            BSF     PORTA, EN

;ZEITSCHLEIFE 4SEC
            MOVLW   D'4'                    ;UNGEFAEHR 4SEC ZEITSCHLEIFE
            MOVWF   HELP2
D1          NOP                             ;T=4
            DECFSZ  HELP2, F                ;T=4
            GOTO    D1                      ;T=8    GES.:16TAKTE * 0,0625SEC= 1SEC    *4 DURCHLAEUFE= 4SEC
;ENDE ZEITSCHLEIFE
 
            BCF     PORTA, EN

;---------------------------------

;LOW 4BIT AUSGEBEN
            RLF     BIT, F
            RLF     BIT, F
            RLF     BIT, F
            RLF     BIT, F

            MOVF    PORTB, W
            ANDLW   0X0F
            MOVWF   MERKE

            MOVF    BIT, W
            ANDLW   0XF0
            ADDWF   MERKE, W
            MOVWF   PORTB


            BSF     PORTA, EN

;ZEITSCHLEIFE 4SEC
            MOVLW   D'4'                    
            MOVWF   HELP2
DDD1        NOP                             
            DECFSZ  HELP2, F                
            GOTO    DDD1                    
;ENDE ZEITSCHLEIFE
 
            BCF     PORTA, EN

;ZEITSCHLEIFE 40SEC
            MOVLW   D'40'                   ;UNGEFAEHR 40SEC ZEITSCHLEIFE
            MOVWF   HELP2
DDDD1       NOP
            DECFSZ  HELP2, F                ;WIE OBEN  
            GOTO    DDDD1
;ENDE ZEITSCHLEIFE

            RETURN

;*****************************************************************************
;*                              UNTERPROG. BEFEHL AUSGEBEN AUF DOT-LCD-MODUL *
;*****************************************************************************
BEFEHL      BCF     PORTA, RS                ;ALS BEFEHL

            MOVWF   BIT

            MOVF    PORTB, W
            ANDLW   0X0F
            MOVWF   MERKE

            MOVF    BIT, W
            ANDLW   0XF0
            ADDWF   MERKE, W
            MOVWF   PORTB

            BSF     PORTA, EN

;ZEITSCHLEIFE 4SEC
            MOVLW   D'4'                    ;UNGEFAEHR 8SEC ZEITSCHLEIFE
            MOVWF   HELP2
B1          NOP                             ;T=4
            DECFSZ  HELP2, F                ;T=4
            GOTO    B1                      ;T=8        GES.:16TAKTE * 0,0625SEC= 1SEC    *4 DURCHLAEUFE= 4SEC
;ENDE ZEITSCHLEIFE
 
            BCF     PORTA, EN

;---------------------------------

;LOW 4BIT AUSGEBEN
            RLF     BIT, F
            RLF     BIT, F
            RLF     BIT, F
            RLF     BIT, F

            MOVF    PORTB, W
            ANDLW   0X0F
            MOVWF   MERKE

            MOVF    BIT, W
            ANDLW   0XF0
            ADDWF   MERKE, W
            MOVWF   PORTB

            BSF     PORTA, EN

;ZEITSCHLEIFE 4SEC
            MOVLW   D'4'                    
            MOVWF   HELP2
BBB1        NOP                             
            DECFSZ  HELP2, F                
            GOTO    BBB1                    
;ENDE ZEITSCHLEIFE
 
            BCF     PORTA, EN

;ZEITSCHLEIFE 40SEC
            MOVLW   D'40'                   ;UNGEFAEHR 40SEC ZEITSCHLEIFE
            MOVWF   HELP2
BBBB1       NOP
            DECFSZ  HELP2, F                ;WIE OBEN  
            GOTO    BBBB1
;ENDE ZEITSCHLEIFE
 
            RETURN

;*****************************************************************************
;*                              UNTERPROG. TEXT AUSGEBEN AUF DOT-LCD-MODUL   *
;*****************************************************************************
GEHTLOS
            MOVLW   H'80'                   ;ADRESSE 0 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'81'                   ;ADRESSE 1
            CALL    BEFEHL
            MOVLW   "S"
            CALL    DATEN

            MOVLW   H'82'                   ;ADRESSE 2
            CALL    BEFEHL
            MOVLW   "E"
            CALL    DATEN

            MOVLW   H'83'                   ;ADRESSE 3
            CALL    BEFEHL
            MOVLW   "R"
            CALL    DATEN

            MOVLW   H'84'                   ;ADRESSE 4
            CALL    BEFEHL
            MOVLW   "V"
            CALL    DATEN

            MOVLW   H'85'                   ;ADRESSE 5
            CALL    BEFEHL
            MOVLW   "O"
            CALL    DATEN

            MOVLW   H'86'                   ;ADRESSE 6
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'87'                   ;ADRESSE 7
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN
            RETURN
            
;*****************************************************************************
;*                              UNTERPROG. TEXT AUSGEBEN AUF DOT-LCD-MODUL   *
;*****************************************************************************
MS
            MOVLW   H'86'                   ;ADRESSE 6
            CALL    BEFEHL
            MOVLW   0X6D                    ;M
            CALL    DATEN
            
            MOVLW   H'87'                   ;ADRESSE 7
            CALL    BEFEHL
            MOVLW   0X73                    ;S
            CALL    DATEN

            MOVLW   H'84'                   ;ADRESSE 4
            CALL    BEFEHL
            MOVLW   0X30                    ;0
            CALL    DATEN

            MOVLW   H'81'                   ;ADRESSE 1
            CALL    BEFEHL
            MOVLW   0X2E                    ;'.'
            CALL    DATEN

            RETURN
            
;*****************************************************************************
;*                                         LSCHEN DISPLAY                   *
;*****************************************************************************
LOE  
            MOVLW   H'01'                   ;CLEAR DISPLAY
            CALL    BEFEHL
            MOVLW   D'1'                    ;EIGENTLICH NUR 5MSEC ZEITSCHLEIFE MUSS DRIN SEIN !!! NACH CLEAR...
            CALL    ZS10MSEC                ;UNTERPROGRAMM VON DEM ZEITSCHLEIFEN-BESCHREIBUNGEN HER NEHMEN
            RETURN
            
            
END
